beamtools.apply_multipart_beam_spanner_to_bottommost_tuplets_in_expr
====================================================================

.. autofunction:: abjad.tools.beamtools.apply_multipart_beam_spanner_to_bottommost_tuplets_in_expr.apply_multipart_beam_spanner_to_bottommost_tuplets_in_expr
   :noindex:
